@@ -4,6 +4,10 @@
 #' descriptions see
 #' [ImageMagick Enumerations](https://www.imagemagick.org/Magick++/Enumerations.html).
 #'
+#' The [dump_option_info] function is equivalent to calling `convert -list [option]` on
+#' the command line. It does not return anything, it only makes ImageMagick print
+#' stuff to the console, use only for debugging.
+#'
 #' @rdname options
 #' @family image
 #' @name options
@@ -16,6 +20,12 @@ magick_options <- function(){
   Filter(length, sapply(types, list_options))
 }
 
+#' @export
+#' @rdname options
+magick_fonts <- function(){
+  list_font_info()
+}
+
 #' @export
 #' @rdname options
 option_types <- function(){
@@ -117,3 +127,11 @@ compress_types <- function(){
 distort_types <- function(){
   list_options('distort')
 }
+
+#' @export
+#' @rdname options
+#' @param option one of the [option_types]
+dump_option_info <- function(option = 'font'){
+  option <- as.character(option)
+  dump_option_list(c("-list", option))
+}
