@@ -1,4 +1,4 @@
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 dev.off <- function(){
   invisible(grDevices::dev.off())
 }
@@ -7,12 +7,12 @@ dev.off <- function(){
 library(magick)
 str(magick::magick_config())
 
-## ---- eval = require(rsvg, quietly = TRUE)------------------------------------
+## ----eval = require(rsvg, quietly = TRUE)-------------------------------------
 library(magick)
 tiger <- image_read_svg('http://jeroen.github.io/images/tiger.svg', width = 350)
 print(tiger)
 
-## ---- eval = require(rsvg, quietly = TRUE)------------------------------------
+## ----eval = require(rsvg, quietly = TRUE)-------------------------------------
 tiger_png <- image_convert(tiger, "png")
 image_info(tiger_png)
 
@@ -71,8 +71,8 @@ img_blurred <- image_convolve(img, kern)
 image_append(c(img, img_blurred))
 
 ## -----------------------------------------------------------------------------
-img %>% image_convolve('Sobel') %>% image_negate()
-img %>% image_convolve('DoG:0,0,2') %>% image_negate()
+img |> image_convolve('Sobel') |> image_negate()
+img |> image_convolve('DoG:0,0,2') |> image_negate()
 
 ## -----------------------------------------------------------------------------
 # Add some text
@@ -99,24 +99,24 @@ test <- image_annotate(test, "This is how we combine transformations", color = "
 print(test)
 
 ## -----------------------------------------------------------------------------
-image_read("https://jeroen.github.io/images/frink.png") %>%
-  image_rotate(270) %>%
-  image_background("blue", flatten = TRUE) %>%
-  image_border("red", "10x10") %>%
+image_read("https://jeroen.github.io/images/frink.png") |>
+  image_rotate(270) |>
+  image_background("blue", flatten = TRUE) |>
+  image_border("red", "10x10") |>
   image_annotate("The same thing with pipes", color = "white", size = 30)
 
 ## -----------------------------------------------------------------------------
 # Download earth gif and make it a bit smaller for vignette
-earth <- image_read("https://jeroen.github.io/images/earth.gif") %>%
-  image_scale("200x") %>%
+earth <- image_read("https://jeroen.github.io/images/earth.gif") |>
+  image_scale("200x") |>
   image_quantize(128)
 
 length(earth)
 earth
 head(image_info(earth))
 
-rev(earth) %>% 
-  image_flip() %>% 
+rev(earth) |> 
+  image_flip() |> 
   image_annotate("meanwhile in Australia", size = 20, color = "white")
 
 ## -----------------------------------------------------------------------------
@@ -148,7 +148,7 @@ image_append(image_scale(img, "100"), stack = TRUE)
 bigdatafrink <- image_scale(image_rotate(image_background(frink, "none"), 300), "x200")
 image_composite(image_scale(bigdata, "x400"), bigdatafrink, offset = "+180+100")
 
-## ---- eval = require(pdftools, quietly = TRUE)--------------------------------
+## ----eval = require(pdftools, quietly = TRUE)---------------------------------
 manual <- image_read_pdf('https://cloud.r-project.org/web/packages/magick/magick.pdf', density = 72)
 image_info(manual)
 manual[1]
@@ -159,9 +159,9 @@ image_animate(image_scale(img, "200x200"), fps = 1, dispose = "previous")
 ## -----------------------------------------------------------------------------
 newlogo <- image_scale(image_read("https://jeroen.github.io/images/Rlogo.png"))
 oldlogo <- image_scale(image_read("https://jeroen.github.io/images/Rlogo-old.png"))
-image_resize(c(oldlogo, newlogo), '200x150!') %>%
-  image_background('white') %>%
-  image_morph() %>%
+image_resize(c(oldlogo, newlogo), '200x150!') |>
+  image_background('white') |>
+  image_morph() |>
   image_animate(optimize = TRUE)
 
 ## -----------------------------------------------------------------------------
@@ -224,12 +224,12 @@ print(animation)
 ## -----------------------------------------------------------------------------
 plot(as.raster(frink))
 
-## ---- fig.width=7, fig.height=5-----------------------------------------------
+## ----fig.width=7, fig.height=5------------------------------------------------
 # Print over another graphic
 plot(cars)
 rasterImage(frink, 21, 0, 25, 80)
 
-## ---- fig.width=5, fig.height=3-----------------------------------------------
+## ----fig.width=5, fig.height=3------------------------------------------------
 library(ggplot2)
 library(grid)
 qplot(speed, dist, data = cars, geom = c("point", "smooth"))
@@ -238,10 +238,10 @@ grid.raster(frink)
 ## ----eval=FALSE---------------------------------------------------------------
 #  install.packages("tesseract")
 
-## ---- eval = require(tesseract, quietly = TRUE)-------------------------------
-img <- image_read("http://jeroen.github.io/images/testocr.png")
-print(img)
-
-# Extract text
-cat(image_ocr(img))
+## ----eval = require(tesseract, quietly = TRUE)--------------------------------
+#  img <- image_read("http://jeroen.github.io/images/testocr.png")
+#  print(img)
+#  
+#  # Extract text
+#  cat(image_ocr(img))
 
