@@ -5,6 +5,13 @@
 
 #include "magick_types.h"
 
+Magick::CompressionType Compression(const char * str){
+  ssize_t val = MagickCore::ParseCommandOption( MagickCore::MagickCompressOptions, Magick::MagickFalse, str);
+  if(val < 0)
+    throw std::runtime_error(std::string("Invalid CompressionType value: ") + str);
+  return (Magick::CompressionType) val;
+}
+
 XPtrImage magick_image_bitmap(void * data, Magick::StorageType type, size_t slices, size_t width, size_t height){
   const char * format;
   switch ( slices ){ //TODO: K is blackchannel, there should be a 'graychannel' instead? (G = Green!)
@@ -60,7 +67,8 @@ XPtrImage magick_image_readbitmap_double(Rcpp::NumericVector x){
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_readbin(Rcpp::RawVector x, Rcpp::CharacterVector density, Rcpp::IntegerVector depth, bool strip = false){
+XPtrImage magick_image_readbin(Rcpp::RawVector x, Rcpp::CharacterVector density, Rcpp::IntegerVector depth,
+                               bool strip, Rcpp::CharacterVector defines){
   XPtrImage image = create();
 #if MagickLibVersion >= 0x689
   Magick::ReadOptions opts = Magick::ReadOptions();
@@ -71,6 +79,11 @@ XPtrImage magick_image_readbin(Rcpp::RawVector x, Rcpp::CharacterVector density,
     opts.density(std::string(density.at(0)).c_str());
   if(depth.size())
     opts.depth(depth.at(0));
+  if(defines.size()){
+    Rcpp::CharacterVector names = defines.names();
+    for(int i = 0; i < defines.size(); i++)
+      MagickCore::SetImageOption(opts.imageInfo(), names.at(i), defines.at(i));
+  }
   Magick::readImages(image.get(), Magick::Blob(x.begin(), x.length()), opts);
 #else
   Magick::readImages(image.get(), Magick::Blob(x.begin(), x.length()));
@@ -81,7 +94,8 @@ XPtrImage magick_image_readbin(Rcpp::RawVector x, Rcpp::CharacterVector density,
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_readpath(Rcpp::CharacterVector paths, Rcpp::CharacterVector density, Rcpp::IntegerVector depth, bool strip = false){
+XPtrImage magick_image_readpath(Rcpp::CharacterVector paths, Rcpp::CharacterVector density, Rcpp::IntegerVector depth,
+                                bool strip, Rcpp::CharacterVector defines){
   XPtrImage image = create();
 #if MagickLibVersion >= 0x689
   Magick::ReadOptions opts = Magick::ReadOptions();
@@ -92,6 +106,11 @@ XPtrImage magick_image_readpath(Rcpp::CharacterVector paths, Rcpp::CharacterVect
     opts.density(std::string(density.at(0)).c_str());
   if(depth.size())
     opts.depth(depth.at(0));
+  if(defines.size()){
+    Rcpp::CharacterVector names = defines.names();
+    for(int i = 0; i < defines.size(); i++)
+      MagickCore::SetImageOption(opts.imageInfo(), names.at(i), defines.at(i));
+  }
   for(int i = 0; i < paths.size(); i++)
     Magick::readImages(image.get(), std::string(paths[i]), opts);
 #else
@@ -117,7 +136,8 @@ XPtrImage magick_image_read_list(Rcpp::List list){
 
 // [[Rcpp::export]]
 Rcpp::RawVector magick_image_write( XPtrImage input, Rcpp::CharacterVector format, Rcpp::IntegerVector quality,
-                                    Rcpp::IntegerVector depth, Rcpp::CharacterVector density, Rcpp::CharacterVector comment){
+                                    Rcpp::IntegerVector depth, Rcpp::CharacterVector density, Rcpp::CharacterVector comment,
+                                    Rcpp::CharacterVector compression){
   if(!input->size())
     return Rcpp::RawVector(0);
   XPtrImage image = copy(input);
@@ -137,6 +157,8 @@ Rcpp::RawVector magick_image_write( XPtrImage input, Rcpp::CharacterVector forma
   }
   if(comment.size())
     for_each ( image->begin(), image->end(), Magick::commentImage(std::string(comment.at(0))));
+  if(compression.size())
+    for_each ( image->begin(), image->end(), Magick::compressTypeImage(Compression(std::string(compression.at(0)).c_str())));
   Magick::Blob output;
   writeImages( image->begin(), image->end(),  &output );
   Rcpp::RawVector res(output.length());
@@ -208,10 +230,19 @@ XPtrImage magick_image_fft( XPtrImage image){
 }
 
 // [[Rcpp::export]]
-XPtrImage magick_image_montage( XPtrImage image){
+XPtrImage magick_image_montage( XPtrImage image, Rcpp::CharacterVector geometry, Rcpp::CharacterVector tile,
+                                Rcpp::CharacterVector gravity, std::string bg = "white", bool shadow = false){
   XPtrImage out = create();
-  Magick::Montage montageOpts = Magick::Montage();
-  montageImages(out.get(), image->begin(), image->end(), montageOpts);
+  Magick::Montage opts = Magick::Montage();
+  if(geometry.length())
+    opts.geometry(Geom(geometry.at(0)));
+  if(tile.length())
+    opts.tile(Geom(tile.at(0)));
+  if(gravity.length())
+    opts.gravity(Gravity(gravity.at(0)));
+  opts.shadow(shadow);
+  opts.backgroundColor(bg);
+  montageImages(out.get(), image->begin(), image->end(), opts);
   return out;
 }
 
@@ -248,3 +279,24 @@ XPtrImage magick_image_combine( XPtrImage input, const char * colorspace, const
   output->push_back(x);
   return output;
 }
+
+// [[Rcpp::export]]
+XPtrImage magick_image_set_define( XPtrImage input, Rcpp::CharacterVector format,
+                                   Rcpp::CharacterVector name, Rcpp::CharacterVector value){
+  //NB: do NOT copy; modifies
+  if(!format.length() || !name.length() || !value.length())
+    throw std::runtime_error("Missing format or key");
+  std::string val(value.at(0));
+  std::string fmt(format.at(0));
+  std::string key(name.at(0));
+  for(size_t i = 0; i < input->size(); i++){
+    if(!val.length()){
+      input->at(i).defineSet(fmt, key, true); // empty string
+    } else if(Rcpp::CharacterVector::is_na(value.at(0))) {
+      input->at(i).defineSet(fmt, key, false); // unset
+    } else {
+      input->at(i).defineValue(fmt, key, val);
+    }
+  }
+  return input;
+}
